==> amity-sdk-7.6.0-alpha02-sources.jar: main/com/amity/socialcloud/sdk/social/domain/post/create/ClipPostCreateUseCase.kt <==
package com.amity.socialcloud.sdk.social.domain.post.create

import com.amity.socialcloud.sdk.model.core.error.AmityError
import com.amity.socialcloud.sdk.model.core.error.AmityException
import com.amity.socialcloud.sdk.model.core.file.AmityClip
import com.amity.socialcloud.sdk.model.social.post.AmityPost
import com.amity.socialcloud.sdk.social.data.post.PostRepository
import com.amity.socialcloud.sdk.social.domain.post.PostGetUseCase
import com.ekoapp.ekosdk.internal.usecase.post.PostCreateUseCase
import com.google.gson.JsonObject
import io.reactivex.rxjava3.core.Single

internal class ClipPostCreateUseCase : PostCreateUseCase {

    fun execute(
        targetType: String,
        targetId: String,
        clip: AmityClip,
        text: String,
        fileId: String,
        displayMode: AmityClip.DisplayMode,
        isMuted: Boolean = false,
        metadata: JsonObject?,
        mentionUserIds: List<String>?,
    ): Single<AmityPost> {
        return PostRepository().createPostV4(
            targetType = targetType,
            targetId = targetId,
            data = composeData(text),
            attachments = mapAttachments(
                files = listOf(clip),
                dataType = AmityPost.DataType.CLIP.getApiKey(),
                fileId = fileId,
                displayMode = displayMode.apiString,
                isMuted = isMuted
            ),
            metadata = metadata,
            mentionees = mapMentionees(mentionUserIds)
        ).flatMap {
            val post = PostGetUseCase().execute(it)
            if (post != null) {
                Single.just(post)
            } else {
                Single.error(
                    AmityException.create(
                        "Post not found",
                        null,
                        AmityError.ITEM_NOT_FOUND
                    )
                )
            }
        }
    }

    private fun composeData(
        text: String,
    ): JsonObject {
        return JsonObject().apply {
            addProperty("text", text)
        }
    }

}

==> amity-sdk-7.6.1-alpha02-sources.jar: main/com/amity/socialcloud/sdk/social/domain/post/create/ClipPostCreateUseCase.kt <==
package com.amity.socialcloud.sdk.social.domain.post.create

import com.amity.socialcloud.sdk.model.core.error.AmityError
import com.amity.socialcloud.sdk.model.core.error.AmityException
import com.amity.socialcloud.sdk.model.core.file.AmityClip
import com.amity.socialcloud.sdk.model.social.post.AmityPost
import com.amity.socialcloud.sdk.social.data.post.PostRepository
import com.amity.socialcloud.sdk.social.domain.post.PostGetUseCase
import com.ekoapp.ekosdk.internal.usecase.post.PostCreateUseCase
import com.google.gson.JsonObject
import io.reactivex.rxjava3.core.Single

internal class ClipPostCreateUseCase : PostCreateUseCase {

    fun execute(
        targetType: String,
        targetId: String,
        clips: List<AmityClip>,
        text: String,
        fileId: String,
        displayMode: AmityClip.DisplayMode,
        isMuted: Boolean = false,
        metadata: JsonObject?,
        mentionUserIds: List<String>?,
    ): Single<AmityPost> {
        return PostRepository().createPostV4(
            targetType = targetType,
            targetId = targetId,
            data = composeData(text),
            dataType = AmityPost.DataType.CLIP,
            attachments = mapAttachments(
                files = clips,
                dataType = AmityPost.DataType.CLIP.getApiKey(),
                fileId = fileId,
                displayMode = displayMode.apiString,
                isMuted = isMuted
            ),
            metadata = metadata,
            mentionees = mapMentionees(mentionUserIds)
        ).flatMap {
            val post = PostGetUseCase().execute(it)
            if (post != null) {
                Single.just(post)
            } else {
                Single.error(
                    AmityException.create(
                        "Post not found",
                        null,
                        AmityError.ITEM_NOT_FOUND
                    )
                )
            }
        }
    }

    private fun composeData(
        text: String,
    ): JsonObject {
        return JsonObject().apply {
            addProperty("text", text)
        }
    }

}
